library(testthat)
library(devtools)

test_check("rbundler")
